@@ -229,7 +229,7 @@ def centryImage(userImages, teample = 1):
             wpercent = (basewidth / float(userImages.size[0]))
             hsize = int((float(userImages.size[1]) * float(wpercent)))
             userImages = userImages.resize((basewidth, hsize), Image.LANCZOS)
-            return userImages, (0,-34), 2
+            return userImages, (0,0), 2
 
 
 def openImageElement(element,teample = 1):
